@@ -3,7 +3,6 @@ module Main (main) where
 import           Codec.Compression.BZip
 import           Control.Concurrent     (forkIO, newEmptyMVar, putMVar, readMVar)
 import           Control.DeepSeq        (deepseq)
-import           Control.Exception      (evaluate, try)
 import qualified Data.ByteString.Lazy   as BSL
 import           System.Directory       (doesFileExist)
 import           System.FilePath        ((-<.>))
@@ -16,10 +15,10 @@ testDecompress fp =
     goldenVsString ("Decompress " ++ fp) (fp -<.> ".ref") (decompress <$> BSL.readFile fp)
 
 forceHead :: BSL.ByteString -> IO ()
-forceHead bsl = head (BSL.toChunks bsl) `seq` (pure ())
+forceHead bsl = head (BSL.toChunks bsl) `seq` pure ()
 
 forceBSL :: BSL.ByteString -> IO ()
-forceBSL bsl = last (BSL.toChunks bsl) `seq` (pure ())
+forceBSL bsl = last (BSL.toChunks bsl) `seq` pure ()
 
 testCompress :: FilePath -> TestTree
 testCompress fp = testCase ("Roundtrip " ++ fp) $ do
